@@ -1,10 +1,12 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2018-2024, by Samuel Williams.
+# Copyright, 2018-2025, by Samuel Williams.
 
 require_relative "connection"
 
+require "traces/provider"
+
 module Async
 	module HTTP
 		module Protocol
@@ -37,7 +39,16 @@ module Async
 						
 						# We carefully interpret https://tools.ietf.org/html/rfc7230#section-6.3.1 to implement this correctly.
 						begin
-							write_request(request.authority, request.method, request.path, @version, request.headers)
+							target = request.path
+							authority = request.authority
+							
+							# If we are using a CONNECT request, we need to use the authority as the target:
+							if request.connect?
+								target = authority
+								authority = nil
+							end
+							
+							write_request(authority, request.method, target, @version, request.headers)
 						rescue
 							# If we fail to fully write the request and body, we can retry this request.
 							raise RequestFailed
@@ -79,6 +90,20 @@ module Async
 						self.close(error)
 						raise
 					end
+					
+					Traces::Provider(self) do
+						def write_request(...)
+							Traces.trace("async.http.protocol.http1.client.write_request") do
+								super
+							end
+						end
+						
+						def read_response(...)
+							Traces.trace("async.http.protocol.http1.client.read_response") do
+								super
+							end
+						end
+					end
 				end
 			end
 		end
